@@ -26,8 +26,8 @@ import sys
 import socket
 import time
 from os.path import expanduser
-from PyQt4 import QtGui, QtCore
-from PyQt4.QtCore import QThread
+from PyQt5 import QtGui, QtCore, QtWidgets
+from PyQt5.QtCore import QThread
 from gqrxHamlib import gqrxHamlibGUI
 #import xmlrpc.client
 
@@ -275,7 +275,7 @@ class startControl(QThread):
             data = self.server.rig.set_mode(str(mode))
         return data
        
-class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
+class gqrxHamlib(QtWidgets.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
     def __init__(self):
         super(self.__class__, self).__init__()
         self.setupUi(self)
@@ -300,6 +300,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton.clicked.connect(self.gqrxhamlibSync)
             self.pushButton_3.clicked.connect(self.hamlibControl)
             self.pushButton_4.clicked.connect(self.hamlibControlOneoff)
+            self.pushButton_8.clicked.connect(self.hamlibControlOneoff)
              
         self.pushButton_2.clicked.connect(self.gqrxControl)
         self.pushButton_6.clicked.connect(self.gqrxControlOneoff)
@@ -390,6 +391,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: green")
             self.pushButton_4.setStyleSheet("background-color: red")
+            self.pushButton_8.setStyleSheet("background-color: red")
         self.pushButton_2.setStyleSheet("background-color: green")
         self.pushButton_6.setStyleSheet("background-color: green")
         self.control = 3
@@ -400,6 +402,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
         self.controlThread.reportErr.connect(self.reportErrMsg)
         self.controlThread.start()
         self.pushButton_4.setStyleSheet("background-color: green")
+        self.pushButton_8.setStyleSheet("background-color: green")
         self.control = 0
         
     def readConfig(self):
@@ -441,6 +444,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: grey")
             self.pushButton_4.setStyleSheet("background-color: grey")
+            self.pushButton_8.setStyleSheet("background-color: grey")
             self.pushButton_6.setStyleSheet("background-color: green")
         else:
             self.panadaptor.setChecked(False)
@@ -448,6 +452,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: green")
             self.pushButton_4.setStyleSheet("background-color: green")
+            self.pushButton_8.setStyleSheet("background-color: green")
             self.pushButton_6.setStyleSheet("background-color: green")
         cf.close()
             
@@ -468,6 +473,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: grey")
             self.pushButton_4.setStyleSheet("background-color: grey")
+            self.pushButton_8.setStyleSheet("background-color: grey")
             self.pushButton_6.setStyleSheet("background-color: green")
         else:
             self.ifModev = 'N'
@@ -475,6 +481,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.pushButton_2.setStyleSheet("background-color: green")
             self.pushButton_3.setStyleSheet("background-color: green")
             self.pushButton_4.setStyleSheet("background-color: green")
+            self.pushButton_8.setStyleSheet("background-color: green")
             self.pushButton_6.setStyleSheet("background-color: green")
         configLine = self.gqrxIPv+','+self.gqrxPortv+','+self.hamlibIPv+','+self.hamlibPortv+','+self.modev+','+self.ifModev+','+self.ifFreqv
         cf.write(configLine)
@@ -490,7 +497,7 @@ class gqrxHamlib(QtGui.QMainWindow, gqrxHamlibGUI.Ui_MainWindow):
             self.stopThread()
 
 def main():
-    app = QtGui.QApplication(sys.argv)
+    app = QtWidgets.QApplication(sys.argv)
     form = gqrxHamlib()
     form.show()
     app.exec_()
